@@ -181,14 +181,12 @@ my %determiners = (
     'ReflectionEffect' => {  },
     'ResourceBase' => {  },
     'ResourceUri' => {  },
-    'ScaleType' => {  },
     'Series' => {  },
     'SeriesMarker' => {  },
     'ShapeExportFormat' => {  },
     'ShapeImageExportOptions' => {  },
     'ShapeThumbnailBounds' => {  },
     'ShapesAlignmentType' => {  },
-    'SizeType' => {  },
     'SlideComment' => {  },
     'SlideExportFormat' => {  },
     'SmartArtNode' => {  },
